@@ -27,7 +27,7 @@ DUMPING = False
 # recognized by regular expressions.  All regular expressions must be
 # tried, obviously.  The first one that matches is taken, and no order
 # is specified.  Try to avoid overlapping patterns.
-class ArgumentListFilter(object):
+class ArgumentListFilter:
     def __init__(self, inputList, exactMatches={}, patternMatches={}):
         defaultArgExactMatches = {
 
@@ -153,6 +153,7 @@ class ArgumentListFilter(object):
             '-ggdb3' : (0, ArgumentListFilter.compileUnaryCallback),
             '-gdwarf-2' : (0, ArgumentListFilter.compileUnaryCallback),
             '-gdwarf-3' : (0, ArgumentListFilter.compileUnaryCallback),
+            '-gdwarf-4' : (0, ArgumentListFilter.compileUnaryCallback),
             '-gline-tables-only' : (0, ArgumentListFilter.compileUnaryCallback),
             '-grecord-gcc-switches': (0, ArgumentListFilter.compileUnaryCallback),
 
@@ -329,6 +330,18 @@ class ArgumentListFilter(object):
                 (arity, handler) = argExactMatches[currentItem]
                 flagArgs = self._shiftArgs(arity)
                 handler(self, currentItem, *flagArgs)
+            elif currentItem == '-Wl,--start-group':
+                linkingGroup = [currentItem]
+                terminated = False
+                while self._inputArgs:
+                    groupCurrent = self._inputArgs.popleft()
+                    linkingGroup.append(groupCurrent)
+                    if groupCurrent == "-Wl,--end-group":
+                        terminated = True
+                        break
+                if not terminated:
+                    _logger.warning('Did not find a closing "-Wl,--end-group" to match "-Wl,--start-group"')
+                self.linkingGroupCallback(linkingGroup)
             else:
                 matched = False
                 for pattern, (arity, handler) in argPatterns.items():
@@ -455,6 +468,10 @@ class ArgumentListFilter(object):
         self.linkArgs.append(flag)
         self.linkArgs.append(arg)
 
+    def linkingGroupCallback(self, args):
+        _logger.debug('linkingGroupCallback: %s', args)
+        self.linkArgs.extend(args)
+
     #flags common to both linking and compiling (coverage for example)
     def compileLinkUnaryCallback(self, flag):
         _logger.debug('compileLinkUnaryCallback: %s', flag)
@@ -464,16 +481,16 @@ class ArgumentListFilter(object):
     def getOutputFilename(self):
         if self.outputFilename is not None:
             return self.outputFilename
-        elif self.isCompileOnly:
+        if self.isCompileOnly:
             #iam: -c but no -o, therefore the obj should end up in the cwd.
             (_, base) = os.path.split(self.inputFiles[0])
             (root, _) = os.path.splitext(base)
-            return '{0}.o'.format(root)
+            return f'{root}.o'
         return 'a.out'
 
     def getBitcodeFileName(self):
         (dirs, baseFile) = os.path.split(self.getOutputFilename())
-        bcfilename = os.path.join(dirs, '.{0}.bc'.format(baseFile))
+        bcfilename = os.path.join(dirs, f'.{baseFile}.bc')
         return bcfilename
 
     # iam: returns a pair [objectFilename, bitcodeFilename] i.e .o and .bc.
@@ -484,18 +501,18 @@ class ArgumentListFilter(object):
         (_, srcbase) = os.path.split(srcFile)
         (srcroot, _) = os.path.splitext(srcbase)
         if hidden:
-            objbase = '.{0}.o'.format(srcroot)
+            objbase = f'.{srcroot}.o'
         else:
-            objbase = '{0}.o'.format(srcroot)
-        bcbase = '.{0}.o.bc'.format(srcroot)
+            objbase = f'{srcroot}.o'
+        bcbase = f'.{srcroot}.o.bc'
         return [objbase, bcbase]
 
     #iam: for printing our partitioning of the args
     def dump(self):
         efn = sys.stderr.write
-        efn('\ncompileArgs: {0}\ninputFiles: {1}\nlinkArgs: {2}\n'.format(self.compileArgs, self.inputFiles, self.linkArgs))
-        efn('\nobjectFiles: {0}\noutputFilename: {1}\n'.format(self.objectFiles, self.outputFilename))
+        efn(f'\ncompileArgs: {self.compileArgs}\ninputFiles: {self.inputFiles}\nlinkArgs: {self.linkArgs}\n')
+        efn(f'\nobjectFiles: {self.objectFiles}\noutputFilename: {self.outputFilename}\n')
         for srcFile in self.inputFiles:
-            efn('\nsrcFile: {0}\n'.format(srcFile))
+            efn(f'\nsrcFile: {srcFile}\n')
             (objFile, bcFile) = self.getArtifactNames(srcFile)
-            efn('\n{0} ===> ({1}, {2})\n'.format(srcFile, objFile, bcFile))
+            efn(f'\n{srcFile} ===> ({objFile}, {bcFile})\n')
